#
# spec file for package gfxboot
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gfxboot
Version:        4.5.101
Release:        1.0.2.1.sr20250601
Summary:        Graphical Boot Logo for GRUB, LILO and SYSLINUX
License:        GPL-2.0-or-later
Group:          System/Boot
URL:            http://en.opensuse.org/SDB:Gfxboot
Source:         %{name}-%{version}.tar.xz
Source1:        KDE.tar.xz
Source2:        SLED.tar.xz
Source3:        SLES.tar.xz
Source4:        examples.tar.xz
Source5:        openSUSE.tar.xz
Source6:        upstream.tar.xz
BuildRequires:  fdupes
BuildRequires:  freetype2-devel
BuildRequires:  fribidi
BuildRequires:  libxslt
BuildRequires:  nasm
BuildRequires:  perl-HTML-Parser
BuildRequires:  sgml-skel
BuildRequires:  w3m
BuildRequires:  xmlto
Requires:       coreutils
Requires:       cpio
Requires:       dosfstools
Requires:       mktemp
Requires:       mtools
Requires:       perl-HTML-Parser
Requires:       syslinux
Recommends:     %{name}-theme >= 4
ExclusiveArch:  %ix86 x86_64
%perl_requires

%description
Tools to configure the graphics for your GRUB, LILO or SYSLINUX bootloader.

%package        devel
Summary:        Tools for creating a graphical boot logo
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Here you find the necessary programs to create your own graphical boot
logo. The logo can be used with GRUB, LILO or SYSLINUX.

%package        branding-upstream
Summary:        Graphical bootloader upstream theme
Group:          System/Boot
PreReq:         %{name} >= 4
Supplements:    packageand(%{name}:branding-upstream)
Provides:       %{name}-branding = %{version}
Provides:       %{name}-theme = %{version}
Conflicts:      otherproviders(%{name}-branding)

%description branding-upstream
upstream theme for gfxboot (bootloader graphics).

%package        branding-SLES
Summary:        Graphical bootloader SLES theme
Group:          System/Boot
PreReq:         %{name} >= 4
Supplements:    packageand(%{name}:branding-SLES)
Provides:       %{name}-branding = %{version}
Provides:       %{name}-theme = %{version}
Obsoletes:      bootloader-theme-SLES < %{version}
Provides:       bootloader-theme-SLES = %{version}
Conflicts:      otherproviders(%{name}-branding)

%description branding-SLES
SLES theme for gfxboot (bootloader graphics).

%package        branding-SLED
Summary:        Graphical bootloader SLED theme
Group:          System/Boot
PreReq:         %{name} >= 4
Supplements:    packageand(%{name}:branding-SLED)
Provides:       %{name}-branding = %{version}
Provides:       %{name}-theme = %{version}
Obsoletes:      bootloader-theme-NLD < %{version}
Provides:       bootloader-theme-NLD = %{version}
Conflicts:      otherproviders(%{name}-branding)

%description branding-SLED
SLED theme for gfxboot (bootloader graphics).

%package        branding-KDE
Summary:        Graphical bootloader KDE theme
Group:          System/Boot
PreReq:         %{name} >= 4
Supplements:    packageand(%{name}:branding-KDE)
Provides:       %{name}-branding = %{version}
Provides:       %{name}-theme = %{version}
Conflicts:      otherproviders(%{name}-branding)

%description branding-KDE
KDE theme for gfxboot (bootloader graphics).

%prep
%setup -q -a1 -a2 -a3 -a4 -a5 -a6

%build
# fix build
export SUSE_ASNEEDED=0
make X11LIBS=%{_prefix}/X11R6/%{_lib}
make doc
make themes

%install
%make_install
make DESTDIR=%{buildroot} installsrc
rm -rf %{buildroot}/etc/bootsplash/themes/openSUSE/
gzip -9c doc/%{name}.8 >%{name}.8.gz
install -d -m 755 %{buildroot}%{_mandir}/man8
install -m 644 %{name}.8.gz %{buildroot}%{_mandir}/man8
mkdir %{buildroot}/boot
touch %{buildroot}/boot/message

%post branding-upstream
%{name} --update-theme upstream

%post branding-SLES
%{name} --update-theme SLES

%post branding-SLED
%{name} --update-theme SLED

%post branding-KDE
%{name} --update-theme KDE

%files
%{_sbindir}/%{name}
%{_mandir}/man8/%{name}.8.gz
%dir %{_sysconfdir}/bootsplash
%dir %{_sysconfdir}/bootsplash/themes
%doc README.md
%license COPYING

%files devel
%{_sbindir}/%{name}-compile
%{_sbindir}/%{name}-font
%{_sbindir}/gfxtest
%doc doc/%{name}.html
%doc doc/%{name}.txt
%{_datadir}/%{name}

%files branding-upstream
%{_sysconfdir}/bootsplash/themes/upstream
%ghost /boot/message

%files branding-SLES
%{_sysconfdir}/bootsplash/themes/SLES
%ghost /boot/message

%files branding-SLED
%{_sysconfdir}/bootsplash/themes/SLED
%ghost /boot/message

%files branding-KDE
%{_sysconfdir}/bootsplash/themes/KDE
%ghost /boot/message

%changelog
* Sun Jun  1 2025 opensuse-packaging@opensuse.org
- Translated using Weblate (Kabyle) (bsc#1149754)
- 4.5.101
* Sun Jun  1 2025 opensuse-packaging@opensuse.org
- Added translation using Weblate (Kabyle)
- 4.5.100
* Mon Apr 28 2025 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (Taiwan) (zh_TW)) (bsc#1149754)
- 4.5.99
* Mon Apr 28 2025 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (Taiwan) (zh_TW)) (bsc#1149754)
- 4.5.98
* Mon Apr 28 2025 opensuse-packaging@opensuse.org
- Translated using Weblate (Georgian) (bsc#1149754)
- 4.5.97
* Fri Apr 25 2025 opensuse-packaging@opensuse.org
- Translated using Weblate (French) (bsc#1149754)
- 4.5.96
* Sun Mar  2 2025 opensuse-packaging@opensuse.org
- Translated using Weblate (Georgian) (bsc#1149754)
- 4.5.95
* Sat Jun  8 2024 opensuse-packaging@opensuse.org
- Translated using Weblate (Bulgarian) (bsc#1149754)
- 4.5.94
* Fri Jan 12 2024 opensuse-packaging@opensuse.org
- Translated using Weblate (Russian) (bsc#1149754)
- 4.5.93
* Thu Jan 11 2024 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#55
- limit the 'autodown' feature to first key press
- 4.5.92
* Tue Jun 20 2023 opensuse-packaging@opensuse.org
- Translated using Weblate (Dutch) (bsc#1149754)
- 4.5.91
* Sun Mar 12 2023 bittin@opensuse.org
- Translated using Weblate (Swedish) (bsc#1149754)
- 4.5.90
* Fri Mar  3 2023 opensuse-packaging@opensuse.org
- Translated using Weblate (Persian) (bsc#1149754)
- 4.5.89
* Thu Mar  2 2023 opensuse-packaging@opensuse.org
- Translated using Weblate (Persian) (bsc#1149754)
- 4.5.88
* Fri Dec 30 2022 opensuse-packaging@opensuse.org
- Translated using Weblate (Georgian) (bsc#1149754)
- 4.5.87
* Thu Dec 22 2022 opensuse-packaging@opensuse.org
- Translated using Weblate (Kazakh) (bsc#1149754)
- 4.5.86
* Thu Jun  2 2022 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#54
- work around broken Video BIOS: in case VBE video mode list is
  empty, try VESA pre-defined mode numbers (bsc#1199896)
- How to build and view the bincode reference
- 4.5.85
* Wed Apr 27 2022 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovenian) (bsc#1149754)
- 4.5.84
* Wed Jan 26 2022 shundhammer@suse.de
- merge gh#openSUSE/gfxboot#53
- Adapted to new YaST keymap codes
- Adapted default keymap for lang to new YaST keymap codes
  (jsc#SLE-21107)
- Migrate to new kbd also in gfxboot
- 4.5.83
* Thu Jan 20 2022 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak) (bsc#1149754)
- 4.5.82
* Sat Jan  1 2022 opensuse-packaging@opensuse.org
- Translated using Weblate (Arabic) (bsc#1149754)
- 4.5.81
* Wed Dec 29 2021 opensuse-packaging@opensuse.org
- Translated using Weblate (Arabic) (bsc#1149754)
- 4.5.80
* Wed Jul 21 2021 opensuse-packaging@opensuse.org
- Translated using Weblate (Turkish) (bsc#1149754)
- 4.5.79
* Sun Jun  6 2021 opensuse-packaging@opensuse.org
- Translated using Weblate (Italian) (bsc#1149754)
- 4.5.78
* Fri May 28 2021 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan) (bsc#1149754)
- 4.5.77
* Fri May 14 2021 opensuse-packaging@opensuse.org
- Translated using Weblate (Lithuanian) (bsc#1149754)
- 4.5.76
* Thu Apr  8 2021 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#51
- remove changelog file
- update git2log to latest version
- remove .gitignore
- 4.5.75
* Mon Feb  1 2021 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#50
- Do not generate .note.gnu.property section.
- 4.5.74
* Thu Nov  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Move 'make installsrc' to %%install phase, where it belongs to
  (fixes build with RPM 4.16).
* Thu Oct 22 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Hindi) (bsc#1149754)
- 4.5.73
* Tue Oct 13 2020 Jan Engelhardt <jengelh@inai.de>
- Replace old specfile constructs.
* Tue Aug 25 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese) (bsc#1149754)
- 4.5.72
* Wed Aug 12 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Persian) (bsc#1149754)
* Wed Jul 29 2020 sbrabec@suse.cz
- Translated using Weblate (French) (bsc#1149754)
- Translated using Weblate (Galician) (bsc#1149754)
- Translated using Weblate (Hindi) (bsc#1149754)
- Translated using Weblate (Russian) (bsc#1149754)
- Translated using Weblate (Ukrainian) (bsc#1149754)
- Translated using Weblate (Spanish) (bsc#1149754)
- Added translation using Weblate (Persian)
- 4.5.71
* Mon Jun 15 2020 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#48
- add 'default' and 'https' install methods (bsc#1171018)
- adjust config file description
- add https dialog title
- 4.5.70
* Wed May 27 2020 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#46
- add F8-shortcut for language selection (jsc#SLE-12810, jsc#SLE-12479)
- actual implementation of language switch
- 4.5.69
* Tue Apr 14 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Thai) (bsc#1149754)
- 4.5.68
* Tue Apr 14 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Swedish) (bsc#1149754)
* Tue Apr 14 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Indonesian) (bsc#1149754)
* Wed Feb 26 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Spanish) (bsc#1149754)
- 4.5.67
* Tue Feb 11 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Finnish) (bsc#1149754)
- 4.5.66
* Wed Jan 29 2020 opensuse-packaging@opensuse.org
- Translated using Weblate (Finnish) (bsc#1149754)
- 4.5.65
* Thu Jan 16 2020 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#44
- rework font settings (bsc#1159874)
- 4.5.64
* Tue Dec 10 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (German) (bsc#1149754)
- 4.5.63
* Mon Dec  9 2019 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#43
- prepare gfxboot for syslinux 6.x (jsc#SLE-2969)
- adjust gfxtest script to work with syslinux 6.x
- 4.5.62
* Sat Dec  7 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Chinese (China)) (bsc#1149754)
- 4.5.61
* Fri Dec  6 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Danish) (bsc#1149754)
- 4.5.60
* Fri Dec  6 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Czech) (bsc#1149754)
* Thu Dec  5 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak) (bsc#1149754)
- 4.5.59
* Thu Dec  5 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese (Brazil)) (bsc#1149754)
* Thu Dec  5 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (German) (bsc#1149754)
* Thu Dec  5 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese) (bsc#1149754)
- 4.5.58
* Thu Dec  5 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan) (bsc#1149754)
* Thu Dec  5 2019 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#42
- rebuild font file to support latest language additions
- make more boot menu texts translatable
- 4.5.57
* Wed Dec  4 2019 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#21
- Add Kazakh translation.
- Add Kazakh language definition.
- Add Kazakh to the list of languages.
- 4.5.56
* Tue Nov  5 2019 medwin@opensuse.org
- Translated using Weblate (Indonesian) (bsc#1149754)
- 4.5.55
* Tue Oct 29 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Indonesian) (bsc#1149754)
- 4.5.54
* Wed Oct 23 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Estonian) (bsc#1149754)
- 4.5.53
* Tue Oct 22 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Spanish) (bsc#1149754)
- 4.5.52
* Sat Aug 17 2019 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese)
- 4.5.51
* Fri Apr  5 2019 snwint@suse.de
- merge gh#openSUSE/gfxboot#38
- fix SLES splash calculation (bsc#1129387)
- 4.5.50
* Tue Mar 12 2019 opensuse-packaging@opensuse.org
- merge gh#openSUSE/gfxboot#37
- Replace master-boot-code by syslinux version
- 4.5.49
* Tue Feb  5 2019 snwint@suse.de
- merge gh#openSUSE/gfxboot#35
- ensure theme builds are reproducible (bsc#1124165)
- adjust unpack_bootlogo script
- 4.5.48
* Mon Sep 10 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Arabic)
- 4.5.47
* Tue Jun 19 2018 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#34
- rework video mode list composition (bsc#1096971)
- remove obsolete qemu options from gfxboot script
- 4.5.46
* Tue Jun 12 2018 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#33
- don't crash if vbe video mode list is empty (bsc#1096971)
- replace genisoimage with mkisofs
- 4.5.45
* Fri Apr 27 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Greek)
- 4.5.44
* Fri Apr 27 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Greek)
- 4.5.43
* Fri Apr 27 2018 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#32
- update git2log script
- 4.5.42
* Fri Apr 27 2018 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#31
- enhance documentation
- add sample screenshots
* Mon Apr  9 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan)
- 4.5.41
* Tue Apr  3 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Indonesian)
- 4.5.40
* Sat Mar 24 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Spanish)
- 4.5.39
* Thu Mar 22 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese)
- 4.5.38
* Thu Mar 22 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Portuguese)
- 4.5.37
* Thu Mar  8 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Galician)
- 4.5.36
* Sat Mar  3 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Danish)
- 4.5.35
* Thu Mar  1 2018 antoine.belvire@opensuse.org
- Translated using Weblate (French)
* Mon Feb 26 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Dutch)
- 4.5.34
* Wed Feb 21 2018 freek@opensuse.org
- Translated using Weblate (Dutch)
- 4.5.33
* Wed Feb 21 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Ukrainian)
- 4.5.32
* Tue Feb 20 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Finnish)
- 4.5.31
* Tue Feb 20 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Finnish)
- 4.5.30
* Fri Feb  2 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Indonesian)
- 4.5.29
* Wed Jan 31 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Danish)
- 4.5.28
* Wed Jan 31 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Catalan)
- 4.5.27
* Sun Jan 28 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Danish)
- 4.5.26
* Fri Jan 26 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Japanese)
- 4.5.25
* Thu Jan 25 2018 opensuse-packaging@opensuse.org
- Translated using Weblate (Slovak)
* Tue Jan 23 2018 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#29
- add config file entries to specify a title for the main screen
  (bsc#1077188)
- fix bug processing serial menu entries (bsc#1075852)
- 4.5.24
* Thu Oct  5 2017 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#27
- fix linear framebuffer activation (bsc#1061383)
- add gfx mode number and framebuffer address to debug status
- 4.5.23
* Tue Sep 12 2017 wfeldt@opensuse.org
- color bits detection: add workaround for broken vbe info
- better fallback video mode selection
- 4.5.22
* Tue Sep 12 2017 opensuse-packaging@opensuse.org
- bincode: Fix coreboot LFB mode
* Tue Sep 12 2017 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#26
- prefer linear framebuffer modes for drawing (bsc#980570)
* Tue May  9 2017 wfeldt@opensuse.org
- merge gh#openSUSE/gfxboot#24
- fix UK keyboard setting (bsc#1033202)
- 4.5.21
* Wed Nov 23 2016 snwint@suse.com
- merge pr gh#openSUSE/gfxboot#22
- update git2log script
- adjust keymap names to be consistent again (bsc#1009914)
- 4.5.20
* Mon Nov  7 2016 snwint@suse.com
- Update ca.po
- 4.5.19
* Wed Oct 19 2016 snwint@suse.com
- Update ca.po
- Update lt.po
- 4.5.18
* Mon Oct 17 2016 snwint@suse.com
- fix bug calculating video and xvideo options (bsc#780621)
- 4.5.17
* Fri Oct 14 2016 snwint@suse.com
- implement enhanced menu layout engine
- rework video mode menu
- adjust to new menu engine
- adjust to new menu engine
- use new functions to pass on video menu settings to bootloader
- again updated sound samples
- one more text to sample
- ensure sound samples are loaded only once
- re-rendered font
- adjust to changed sox syntax
- updated texts that are run through espeak
- updated sound samples
- 4.5.16
* Tue Sep 13 2016 snwint@suse.com
- Adapted to the new keymaps used by linuxrc and YaST
- 4.5.15
* Mon Aug  8 2016 snwint@suse.com
- fix boot-label redrawing after language change (bsc#988392)
- 4.5.14
* Mon Jun 13 2016 snwint@suse.com
- updated translations
- make 'systemboot' and 'more' menu entries translatable
- 4.5.13
* Fri Dec  4 2015 snwint@suse.com
- fix booting from submenu (bsc#957893)
- 4.5.12
* Thu Nov 12 2015 snwint@suse.com
- documented submenu syntax
- show submenu indicator in RTL layout
- on leaving a submenu, restore cursor position
- implement support for sub-menues (bsc#906990)
- 4.5.11
* Mon Oct 19 2015 snwint@suse.com
- update translations (bsc#950962)
- 4.5.10
* Thu Oct  1 2015 snwint@suse.com
- implement LEAP boot splash
- 4.5.9
* Tue Sep 29 2015 snwint@suse.com
- Add a basic README.md
- 4.5.8
* Tue Oct 14 2014 snwint_jenkins@suse.com
- added 'archive' Makefile target
- updated git2log
- 4.5.7
* Thu Oct  2 2014 snwint@suse.de
- work around memory corruption issue seen on hyper-v (bnc#876640)
- 4.5.6
* Wed Sep 17 2014 snwint@suse.de
- recreated font to match latest translations
- translation update
- remove duplicate 'Default' from po file
- 4.5.5
* Mon Aug 25 2014 snwint@suse.de
- added two more texts to pot file
- 4.5.4
* Mon Aug 25 2014 snwint@suse.de
- adjust network dialog to latest linuxrc
- make 'Upgrade" translatable
- 4.5.3
* Wed Mar  5 2014 snwint@suse.de
- install license file
* Fri Jan 24 2014 snwint@suse.de
- fix compiler warning
- hrvoje.senjan: use FT_SYNTHESIS_H macro
- set min video mode to 1024x576
- remove use-recommended-freetype-include.patch
* Wed Dec 11 2013 hrvoje.senjan@gmail.com
- Added use-recommended-freetype-include.patch -- Freetype upstream
  recommends using their macros together with ft2build include.
  Positive sideeffect is that this patch makes it build with both
  freetype2 2.5.1, and older version
* Mon Oct  1 2012 snwint@suse.de
- start using 'default' video entry
* Wed Mar 28 2012 snwint@suse.de
- ddc test record
- rework monitor detection
- new video selection menu
* Thu Oct 13 2011 snwint@suse.de
- fix isohybrid detection
* Thu Oct 13 2011 snwint@suse.de
- don't set init boot option (bnc#723678)
* Wed Sep 21 2011 coolo@suse.com
- do not package the openSUSE theme here, but leave it up for
  branding-openSUSE
- remove the fdupes again, way too dangerous in this
* Mon Sep 12 2011 toddrme2178@gmail.com
- Added check for duplicate files (fix for RPMLINT warning)
- Added branding provides (fix for RPMLINT warning)
- Modified summaries (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Fri Sep  2 2011 snwint@suse.de
- make systemd default
* Fri Sep  2 2011 snwint@suse.de
- add config option for default init program
- use isolinux-config from package
* Thu Jul  7 2011 snwint@suse.de
- added KDE theme
- update upstream theme
* Thu Jul  7 2011 snwint@suse.de
- added menu to select init variant (bnc#704417)
- fix script in case we are on no branch
* Mon Apr 18 2011 snwint@suse.de
- restore compat with syslinux 3
- fix wrong mem access
- pass back working dir as absolute path
- pass cwd via sysconfig
* Fri Apr  8 2011 snwint@suse.de
- set version to oS 11.5
- rewrite chdir to work without bootloader chdir support
* Thu Feb 24 2011 snwint@suse.de
- default to hd install with isohybrid boot from hd
* Mon Feb 21 2011 snwint@suse.de
- integrated new oS 11.4 branding into git tree
* Sat Feb 19 2011 javier@opensuse.org
- add startup options to data-boot/back.jpg and openSUSE installer
  to data-install/back.jpg
* Fri Jan 28 2011 lnussel@suse.de
- add a packageand to the Supplements so gfxboot-branding* only gets
  installed if gfxboot actually is meant to be installed.
* Thu Jan 27 2011 javier@opensuse.org
- update artwork for 11.4
* Thu Jan 13 2011 snwint@suse.de
- update virtual box support
- fix autoselection of emulator for "gfxboot -p" (bnc#661832)
- add qemu-kvm to the list auf autoselected emulators (bnc#661832)
* Wed Oct 27 2010 snwint@suse.de
- avoid dialogs wider than screen
* Mon Oct  4 2010 snwint@suse.de
- updated translations (bnc#551046)
- updated help text translations (bnc#551046)
- create VERSION and changelog from git repo
* Fri Sep  3 2010 snwint@suse.de
- show real product name on serial console (bnc#634299)
* Thu Aug  5 2010 snwint@suse.de
- add 'lang' option if language has been changed
  [used to be: if != en_US] (bnc#619983)
- keyboard label was not translatable (bnc#610638)
* Mon Jul  5 2010 snwint@suse.de
- updated translations (bnc#619513)
* Fri Jun 25 2010 snwint@suse.de
- updated translations
* Mon May 31 2010 snwint@suse.de
- clear font flags when setting an undefined font (bnc#609755)
* Thu May 20 2010 snwint@suse.de
- turn on ints explicitly
- better memory dump
- don't abuse bit 31 in font pointer (bnc#599478)
* Wed May 19 2010 snwint@suse.de
- fixed openSUSE 11.3 theme
* Tue May 11 2010 jimmac@novell.com
- update background graphics for 11.3
* Fri Apr 30 2010 snwint@suse.de
- strip gfxboot.com related parts from syslinux-3.86 patchset
- added Asturian (bnc#562202)
- fixed examples to work with latest gfxboot.c32
- set valid tss for pm calls
* Fri Apr 16 2010 snwint@suse.de
- reset progress bar status after error
- fix help text formatting
* Fri Apr  9 2010 snwint@suse.de
- add patches for syslinux 3.86
- prefer gfxboot.c32 over gfxboot.com
* Thu Dec 10 2009 snwint@suse.de
- leave more room for timeout indicator (bnc#551718)
- center main menu (bnc#562089)
* Mon Nov 16 2009 snwint@suse.de
- syslinux patch: fix chdir() return value
* Fri Oct 30 2009 snwint@suse.de
- extend interface so it works with gfxboot.c32
- updated translations (bnc#551046)
* Mon Oct 19 2009 snwint@suse.de
- more examples
- fix progress indicator for PXE boot
* Fri Oct 16 2009 snwint@suse.de
- support pxe setup in test script
- added patches for syslinux 3.83
- improved gfxtest script
- added some sample themes
* Mon Oct 12 2009 snwint@suse.de
- added swiss french keymap
- updated speech samples
* Wed Oct  7 2009 snwint@suse.de
- sync keyboard mapping list with yast (bnc#534856)
* Fri Oct  2 2009 snwint@suse.de
- build new font
- enhanced gfxboot-font
- cleaned up po files
- more flexible translation support
- livecd: add F4=kerneloptions
- fix pot file
* Tue Sep 29 2009 snwint@suse.de
- set default install type correctly (bnc#542781)
* Mon Sep 28 2009 snwint@suse.de
- updated language list
- fixed grub picture (bnc#542113)
* Thu Sep 24 2009 snwint@suse.de
- escape weird chars in URLs
* Fri Sep 18 2009 snwint@suse.de
- F-key assignments configurable via gfxboot.cfg
* Tue Sep 15 2009 snwint@suse.de
- added proxy setup (bnc#329668)
* Mon Sep 14 2009 snwint@suse.de
- fix some nasm warnings
- updated 11.2 openSUSE theme (bnc#538949)
- added network config dialog
* Wed Sep  9 2009 snwint@suse.de
- implemented realloc function
- file read works with files of unknown size (-1)
- added basic 'restore' function (via F11)
- Ilyas Bakirov: added Kirghiz support
- allow empty menus
- added new gfxtest script
- support qemu-kvm
- improved gfxtest script; removed old test script
- added --version option to gfxboot
- no fb after F9 for live cd (bnc#526706)
- gfxboot script works with new syslinux
* Sun Jul 12 2009 coolo@novell.com
- disable as-needed to fix build
* Wed Dec  3 2008 snwint@suse.de
- now really update speech samples
* Tue Dec  2 2008 snwint@suse.de
- enabled penguin theme for openSUSE
* Mon Dec  1 2008 snwint@suse.de
- new texts for speech support (bnc#391313)
* Thu Nov 20 2008 snwint@suse.de
- translations, again (bnc#445350)
* Thu Nov 20 2008 snwint@suse.de
- updated translations (bnc#445350)
* Thu Nov 20 2008 snwint@suse.de
- updated translations
- removed special livecd menu text replacements
* Wed Nov 12 2008 snwint@suse.de
- no beep in installed system (fate#303481)
* Fri Nov  7 2008 snwint@suse.de
- fixed 'portuguese' spelling (bnc#442407)
* Thu Nov  6 2008 snwint@suse.de
- all menus have speech support now (bnc#391313)
- speech works with languages != english
- in input lines the char at cursor position is spoken
* Tue Nov  4 2008 snwint@suse.de
- fix last livecd patch
- can replace '_' with space in menu entries
* Tue Nov  4 2008 snwint@suse.de
- for livecds: don't switch to text mode with F9 (bnc#391313)
- obsolete bootloader-theme-* (bnc#441366)
* Fri Oct 17 2008 olh@suse.de
- add ExclusiveArch x86 x86_64
* Thu Oct 16 2008 snwint@suse.de
- new openSUSE theme
* Mon Oct  6 2008 snwint@suse.de
- updated SLES/SLED themes
* Mon Sep 29 2008 snwint@suse.de
- updated SLE themes
* Fri Sep 26 2008 snwint@suse.de
- translations updated
* Thu Sep 25 2008 snwint@suse.de
- added keyboard selection dialog (bnc#422175)
* Thu Sep 25 2008 snwint@suse.de
- better monitor detection (bnc#407786)
- fix default video size selection (bnc#407786)
* Thu Sep 11 2008 snwint@suse.de
- support serial lines (fate#301595)
* Mon Aug 25 2008 snwint@suse.de
- needs fribidi
- really add SLE themes
* Wed Aug 20 2008 snwint@suse.de
- activated SLE themes
* Tue Aug 19 2008 snwint@suse.de
- gfxboot requires perl-HTML-Parser
* Mon Aug 18 2008 snwint@suse.de
- cooperate with mboot module
- enhanced gfxboot script
- fixed bug in gfxboot-font ('--add' option cleared char list)
- support new text formatting tags (<p> & <ul>)
- new help texts
- fix help to better tolerate broken help setup
- bootloader always beeps
* Mon May 26 2008 snwint@suse.de
- make driver update menu configurable
- added 'download url' item to driver update menu
- updated translations
* Mon May 26 2008 snwint@suse.de
- worked on 11.0 theme
* Mon May 19 2008 snwint@suse.de
- turn sound off before loading kernel (bnc#392016)
- partly moved to new theme
- use 32 bit graphics mode for bootloader
* Thu May 15 2008 snwint@suse.de
- rewrote config file parser
- move most layout parameters to config file
* Fri May  9 2008 snwint@suse.de
- show F9 hint
* Fri May  9 2008 snwint@suse.de
- updated translations
* Wed May  7 2008 snwint@suse.de
- 'F9' adds 'braille=1' to command line
* Mon Apr 28 2008 snwint@suse.de
- WAV file playback works again
- added beep when bootloader is ready (fate#303482)
- added 'visually impaired' mode key (F9) (fate#303482)
- added speech output
- added Thai
* Thu Apr 17 2008 snwint@suse.de
- adjusted package requires (bnc#380757)
* Mon Apr 14 2008 snwint@suse.de
- gfxboot doesn't always need a bootloader
* Fri Apr 11 2008 snwint@suse.de
- fix gfxboot script
- create /boot/message in postin
* Thu Apr 10 2008 snwint@suse.de
- gfxboot can handle themes & translations
- fixed typo in gfxboot.cfg
* Tue Apr  8 2008 snwint@suse.de
- added 'gfxboot' (boot screen config tool)
- added man page
- new themes
- package layout changed
* Mon Feb  4 2008 snwint@suse.de
- added optional 'mediacheck'
* Mon Feb  4 2008 snwint@suse.de
- source tree layout changed ('make prep' no longer required)
* Fri Dec 14 2007 snwint@suse.de
- adjust BuildRequires
* Mon Oct  8 2007 snwint@suse.de
- Avi Kivity: SS does not survive switch to PM in KVM (#307194)
* Tue Sep 25 2007 snwint@suse.de
- benventuno -> benvenuto (#327546)
* Fri Sep 14 2007 snwint@suse.de
- fixed building non-openSUSE themes
* Wed Sep 12 2007 snwint@suse.de
- always ask for VBE2 info (to e.g. get 1366x768 listed - #298025)
- new welcome screen animation
* Mon Sep 10 2007 snwint@suse.de
- updated translations
* Wed Aug 22 2007 snwint@suse.de
- fix livecd mode
* Mon Aug 20 2007 snwint@suse.de
- new translations
* Mon Aug 13 2007 snwint@suse.de
- use autohinting for lohit_pa, gulim, FZHeiTi (#299568)
* Fri Aug 10 2007 snwint@suse.de
- allow to set default values for repository
* Thu Aug  9 2007 snwint@suse.de
- change default lang en -> en_US
- updated po files
* Thu Jul 26 2007 snwint@suse.de
- adjusted menu texts
* Tue Jul 24 2007 snwint@suse.de
- no graphics on problematic via boards (#231104)
* Mon Jul 23 2007 snwint@suse.de
- rewrote line edit function
- intro aborted if any key pressed (#219570)
- added Walloon
- added Sinhala
- moved 'install - XXX' variants into submenu, added 'repair' entry (#293827)
- go green
* Thu Mar 15 2007 snwint@suse.de
- basic rtl language support
* Mon Mar 12 2007 snwint@suse.de
- added new languages
- two-line panel
* Fri Feb  9 2007 snwint@suse.de
- different 'Hindi' spelling
* Wed Feb  7 2007 snwint@suse.de
- added Gujarati & Marathi translations
* Wed Feb  7 2007 snwint@suse.de
- added some code to debug monitor detection
- language cleanup
- added new languages
* Mon Jan 22 2007 snwint@suse.de
- fix language/keymap setting (#223518)
* Fri Nov 24 2006 snwint@suse.de
- fixed penguin theme bug (#216991)
- lang menu sometimes shows only locale name
* Mon Nov 20 2006 snwint@suse.de
- translations updated
- minor penguin setup correction
* Fri Nov 17 2006 snwint@suse.de
- adjust 640x480 menu sizes (#221139)
- tuning layout
- make penguins more likely during winter
* Wed Nov 15 2006 snwint@suse.de
- updated documentation
- get initrd size right for progress bar
* Tue Nov 14 2006 snwint@suse.de
- fixed Requires
* Tue Nov 14 2006 snwint@suse.de
- fix doc file permission
* Mon Nov 13 2006 snwint@suse.de
- help text parser rewritten
- new translations
- added final 10.2 theme
* Tue Nov  7 2006 snwint@suse.de
- new translations
* Fri Oct 27 2006 snwint@suse.de
- penguin theme is back
- adjust html help text parser
* Thu Oct 26 2006 snwint@suse.de
- new translations
* Mon Oct 23 2006 snwint@suse.de
- translations updated
- added 'noinstallopt' option to gfxboot.cfg
* Mon Sep 25 2006 snwint@suse.de
- Arabic is back
* Mon Sep 25 2006 snwint@suse.de
- added 'firmware' menu entry
* Wed Sep 20 2006 snwint@suse.de
- support Punjabi (Gurmukhi script)
* Wed Sep 20 2006 snwint@suse.de
- fixed font rendering bug
- added some indic fonts
* Tue Sep 19 2006 snwint@suse.de
- use 4 bit for antialiasing (not 3)
* Tue Sep 19 2006 snwint@suse.de
- fix Estonian support
* Mon Sep 18 2006 ro@suse.de
- correct filelist
* Mon Sep 18 2006 snwint@suse.de
- support antialiased fonts
- added Estonian
- put hard disk install option back in
* Thu Aug 24 2006 snwint@suse.de
- 32 bit rewrite finished
- changed interface to bootloader
* Mon Aug 21 2006 snwint@suse.de
- move to 32 bit, cont.
* Mon Aug  7 2006 snwint@suse.de
- move to 32 bit, cont.
- added 10.2 openSUSE logos
* Tue Aug  1 2006 snwint@suse.de
- started internal rewrite to run all code in 32 bit pm
* Mon Jul 24 2006 snwint@suse.de
- fixed Zen theme
* Wed Jul 19 2006 snwint@suse.de
- added Catalan & Vietnamese
- better debug window
- fixed minor file reading bug
- better internal locale handling
- separated en locale into en_GB & en_US
* Mon Jul 17 2006 snwint@suse.de
- more than one boot option line, finished (#160066)
- added 'about' button
- make it openSUSE
- added xen test config
* Mon Jul 10 2006 snwint@suse.de
- use disk image, not floppy for grub testing
- updated Zen pictures
- made full panel default
- ShiftTab now works
- remove duplicate video modes (#145749)
- menu bar fits menu text width
- made 'Text Mode' translatable (#179582)
- workaround for interlaced mode issue on some ATI cards (#177982)
- use disk image, not floppy for lilo testing
- major code cleanup
- removed ancient compatibility code
- allow more than one boot option line (for xen)
- using beta pictures
* Fri Jun  9 2006 snwint@suse.de
- translations updated
- minor Zen theme change
* Tue May 23 2006 snwint@suse.de
- translations updated
- added Zen texts & theme
* Mon May 22 2006 snwint@suse.de
- add check to handle insufficient real mode handling in Xen on VMX
  machines (#175473)
- allow per menu entry memory checks via mem.min[<label>] and
  mem.msg[<label>] in gfxboot.cfg
* Mon May 15 2006 snwint@suse.de
- fix random memory corruption when trying to open a nonexistent
  file (#165846)
* Tue May  2 2006 snwint@suse.de
- translations updated (#170561)
* Thu Apr 27 2006 snwint@suse.de
- implemented inbyte/outbyte to access i/o space (#170167)
* Wed Apr 19 2006 snwint@suse.de
- fix drawing bug (#166914)
* Fri Apr  7 2006 snwint@suse.de
- translations updated
- fine-tuned splash
* Tue Apr  4 2006 snwint@suse.de
- fixed Khmer menu entry
* Mon Apr  3 2006 snwint@suse.de
- fixed evil memory corruption bug
* Fri Mar 31 2006 snwint@suse.de
- added 'share' input field for smb install
- some more texts are translatable
- Live-CD preparations
* Thu Mar 30 2006 snwint@suse.de
- adjusted 640x480 fallback layout
- added driver update dialog that lets you enter the update file name
* Wed Mar 29 2006 snwint@suse.de
- better 'welcome' screen
* Tue Mar 28 2006 snwint@suse.de
- added new 'welcome' screen
* Mon Mar 27 2006 snwint@suse.de
- translations updated
* Mon Mar 13 2006 snwint@suse.de
- added NLD & SLES themes
* Mon Mar  6 2006 snwint@suse.de
- new theme, cont.
- it's now nolapic (#155280)
- translations updated
* Tue Feb 28 2006 snwint@suse.de
- drop dosemu as testing platform
- new theme, first try
* Tue Feb 21 2006 snwint@suse.de
- add noapic boot option (#150030)
* Tue Feb 14 2006 snwint@suse.de
- add apic boot option (#150030)
* Thu Feb  9 2006 snwint@suse.de
- more defensive monitor detection (#149578)
- monitor detection can be skipped
* Thu Jan 26 2006 snwint@suse.de
- go for 8 bit framebuffer if there are no 16 bit modes (#144742)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 snwint@suse.de
- better monitor detection
- cjwatson@ubuntu.com: support big-endian cpio archives (#140119)
- support direct driverupdate loading from CD-ROM (feat #152)
- add new languages
* Mon Jan 16 2006 snwint@suse.de
- show all options in grub/lilo (#136377)
- translations & font updated
* Wed Dec 14 2005 snwint@suse.de
- fixed to work correctly with grub & lilo
* Mon Dec  5 2005 snwint@suse.de
- Colin Watson <cjwatson@ubuntu.com>: build fixes for x86-64
- fixed kernel splash loading
- include 'unpack_bootlogo' script in package
* Wed Nov 30 2005 snwint@suse.de
- adjust to syslinux 3.11
- remove some primary words and reimplement them as bytecode
- read config options from 'gfxboot.cfg'
* Wed Oct 19 2005 snwint@suse.de
- offer Croatian
* Wed Oct 12 2005 snwint@suse.de
- do only aligned dword reads from video memory - some ATI boards
  need this (#114804)
* Fri Oct  7 2005 snwint@suse.de
- needs syslinux with updated gfx patch
- texts updated for 10.1
- implemented filesize, getcwd, chdir commands
- using new cd layout
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Tue Sep 20 2005 snwint@suse.de
- better testing script
- gcc 4.1 compile fixes
* Fri Sep  9 2005 snwint@suse.de
- oops, was already December
* Mon Sep  5 2005 snwint@suse.de
- Finnish texts updated
* Fri Sep  2 2005 snwint@suse.de
- fix color handling bug (#72232)
- show penguins a bit more often
* Mon Aug 29 2005 snwint@suse.de
- added more keymaps (#113265)
- long menus are wrapped
- added 640x480 fallback for i845-like boards
- new translations
* Wed Aug 24 2005 snwint@suse.de
- a different shade of blue
- fixed penguin theme drawing bug
* Mon Aug 22 2005 snwint@suse.de
- new translations
* Mon Aug 22 2005 snwint@suse.de
- prepare for jpeg decompression to 8-bit color space
- add penguin theme
- Dansk keymap added
* Mon Aug 15 2005 snwint@suse.de
- fixed Dansk locale (#104084)
- new translations added
* Fri Aug  5 2005 snwint@suse.de
- texts updated
- support images with alpha channel
- new theme
* Thu Jun 23 2005 snwint@suse.de
- 32 bit modes now fully supported
* Wed Jun 22 2005 snwint@suse.de
- updated documentation
* Wed Apr 27 2005 snwint@suse.de
- harddisk install option gone (#60128)
* Fri Apr 22 2005 snwint@suse.de
- added live cd entry
- fixed 16 bit color mode selection (#79312)
* Wed Apr 20 2005 snwint@suse.de
- taiwan text fix (#78946)
* Mon Apr 11 2005 snwint@suse.de
- fixed file reading
* Mon Mar 21 2005 snwint@suse.de
- added slowenic translations
* Wed Mar 16 2005 snwint@suse.de
- new graphics
* Wed Mar 16 2005 snwint@suse.de
- speedup transparent menu drawing
- adjust some colors
* Tue Mar 15 2005 snwint@suse.de
- updated translations
* Tue Mar  8 2005 snwint@suse.de
- fixed install source dialogs
- fixed some memory leaks
* Mon Mar  7 2005 snwint@suse.de
- translation fix (#66743)
- new splash graphics
- fixed slow timeout (#66730)
- enabled transparent menus
* Tue Mar  1 2005 snwint@suse.de
- new graphics
- more translation texts fixes
- prepared for transparent menus
* Tue Feb 22 2005 snwint@suse.de
- fixed translation texts
- ask for smb domain
- corrected minor drawing error
* Mon Feb 21 2005 snwint@suse.de
- 9.3 theme
- fixed color handling bug
* Tue Feb 15 2005 snwint@suse.de
- sync language list with yast2
- fixed making slp default
* Mon Feb 14 2005 snwint@suse.de
- allow selecting slp or cdrom as default install target
* Tue Feb  8 2005 snwint@suse.de
- support ukrainian
* Fri Feb  4 2005 snwint@suse.de
- use 8x16 console font (8x14 does not always exist)
- avoid overlap with bootloader memory usage
- fixed memory addressing problem
* Tue Feb  1 2005 snwint@suse.de
- workaround to avoid memory corruption
- added experimental mouse code (for testing)
* Mon Jan 31 2005 snwint@suse.de
- rewrote internal memory management
- jpeg decoding works
- support symlinks in cpio archive
- lots of minor fixes
- renamed files to stick to 8.3 scheme
- much improved test script
- use bold font
- use 800x600, 16bit color
- added new help texts
- can read files from file system (with syslinux)
* Wed Oct  6 2004 snwint@suse.de
- removed temp file
* Tue Oct  5 2004 snwint@suse.de
- added help text for '64bit' switch (#46806)
* Fri Oct  1 2004 snwint@suse.de
- new blue theme
* Fri Oct  1 2004 snwint@suse.de
- polish translations
- hide passwords (#46094)
* Mon Sep 27 2004 snwint@suse.de
- more languages
* Mon Sep 20 2004 snwint@suse.de
- minor i18n fixes
* Mon Sep 13 2004 snwint@suse.de
- final graphics
- added new translations
* Mon Sep  6 2004 ro@suse.de
- added missing el symlink n Home theme
* Mon Sep  6 2004 snwint@suse.de
- do the F-key-move-down magic only for syslinux (#44238)
- some text cleanup (9.1 -> 9.2, dropped unused liveeval msgs)
- added new translations
- preliminary SuSE theme graphics
* Wed Aug 18 2004 snwint@suse.de
- better arabic language support
* Mon Aug 16 2004 snwint@suse.de
- added arabic
* Mon Aug  9 2004 snwint@suse.de
- add 32/64 dualboot code
- removed obsolete themes
- switch to 'installation' if some F-key has been used (#41097)
- don't offer 640x480; instead, select x11 vesa driver
- assume monitor can display at least 800x600
* Wed May 12 2004 snwint@suse.de
- hide password in lilo (#40348)
* Fri Apr 16 2004 snwint@suse.de
- irqs might have been turned off in some cases
- new SLES pictures
* Wed Apr 14 2004 snwint@suse.de
- font creation missed some chars (#38223)
* Thu Apr  8 2004 snwint@suse.de
- add SuSE-Live theme
- use 'install=slp://' (#36982)
- add new 'biosmem' function
- live cd layout changes
- added live cd warning if there's not enough memory
- added SLES theme (copy of SuSE theme)
* Tue Apr  6 2004 snwint@suse.de
- handle case where we can't set graphics mode (#35806)
* Mon Apr  5 2004 snwint@suse.de
- add HTTP install option
* Mon Apr  5 2004 snwint@suse.de
- add only english to boot/message (#38339)
* Mon Apr  5 2004 snwint@suse.de
- japanese translations, again
- new boot graphics, again
* Sat Apr  3 2004 snwint@suse.de
- new japanese translations (#38224)
- not all japanese chars were added to font (#38223)
* Fri Apr  2 2004 snwint@suse.de
- new boot graphics
* Fri Apr  2 2004 snwint@suse.de
- reset timeout if we show some popup during start
* Fri Apr  2 2004 snwint@suse.de
- added amd64 test
- fixed lilo password dialog
- use less memory for input dialogs
- modplayer should work again
- added russian texts
* Wed Mar 31 2004 snwint@suse.de
- take out romanian install help text; not enough space
* Wed Mar 31 2004 snwint@suse.de
- swedish texts
- added japanese texts
- fixed html viewer to work with japanese (allow line
  breaks at any place)
- added hungarian, italian and french texts
* Mon Mar 29 2004 snwint@suse.de
- dutch help texts
- slovene & romanian texts
* Mon Mar 29 2004 snwint@suse.de
- menu texts localized via 'translations.<locale>'
- new boot graphics
- added Home theme
- fixed language setting (#37195)
- pass lang info to yast (#35841)
* Mon Mar 22 2004 snwint@suse.de
- new boot graphics
- fixed japanese locale name (#36487)
- added spanish texts
- added dutch & hungarian texts
- localized driver update text
* Wed Mar 17 2004 snwint@suse.de
- new/updated czech texts
- reworked themes Makefile
* Tue Mar 16 2004 snwint@suse.de
- german help texts
* Mon Mar 15 2004 snwint@suse.de
- lang menu constructed from 'languages' file
* Tue Mar  9 2004 snwint@suse.de
- added 'SLP' menu entry
* Mon Mar  8 2004 snwint@suse.de
- fixed Makefile
* Mon Mar  8 2004 snwint@suse.de
- czech translations
- added dialogs for various install types
- added 'profiles' menu for laptop people (#32346)
* Mon Mar  1 2004 snwint@suse.de
- use translated language names
* Mon Mar  1 2004 snwint@suse.de
- fixed theme Makefile
* Mon Mar  1 2004 snwint@suse.de
- put texts into *.po files
- redraw screen after selecting new language
- some more keymaps
* Mon Feb 16 2004 snwint@suse.de
- obsoletes gfxboot-devel
* Mon Jan 26 2004 snwint@suse.de
- utf8 support, hi & true color video modes
- german keyboard mapping really works
- reworked much of the internals
- bootlogo file is now normal cpio archive; makes it easier to modify
* Tue Dec 16 2003 snwint@suse.de
- moved SLSS theme to 9.0
- support disk change popups
* Wed Nov 12 2003 varkoly@suse.de
- added SLSS theme for the AutoinstallationsCD  of the
  SuSE Linux School Server Clients
* Mon Oct 13 2003 snwint@suse.de
- added LiveEval theme
* Wed Sep 17 2003 snwint@suse.de
- make F3 actually do something
* Mon Sep 15 2003 snwint@suse.de
- add splash parameter only if it's already there (#28780)
* Sat Sep  6 2003 snwint@suse.de
- added splash mode selection to install screen
* Mon Sep  1 2003 snwint@suse.de
- SuSE theme updated
* Mon Sep  1 2003 snwint@suse.de
- new SuSE theme
- removed eject button; doesn't work on too much systems
- give additional hint if user forgot to turn the dvd over
* Mon Aug 25 2003 snwint@suse.de
- reworked ps code
- added eject dialog for DVD2
- support some european keyboard layouts (experimental: press F9)
* Mon Aug 18 2003 snwint@suse.de
- minor bug in SuSE theme
* Mon Aug 18 2003 snwint@suse.de
- new version; cleaned up package
* Mon Mar 17 2003 snwint@suse.de
- limit max resolution we offer to 1280x1024
* Fri Mar 14 2003 snwint@suse.de
- minor help text corrections (#25139)
* Wed Mar 12 2003 snwint@suse.de
- really final splash pictures
* Mon Mar 10 2003 snwint@suse.de
- final splash picture
* Sat Mar  8 2003 snwint@suse.de
- don't wait 3 seconds in lilo/grub mode
- get default splash mode from grub config
- added splash mode 'native' (splash=0)
* Thu Mar  6 2003 snwint@suse.de
- updated menu texts
- show splash 3 seconds
* Mon Mar  3 2003 snwint@suse.de
- slightly improved SuSE-splash.pcx
- support more kernel splash sizes
* Sat Mar  1 2003 snwint@suse.de
- show splash before boot menu
- build different versions for installer and grub/lilo
* Mon Feb 24 2003 snwint@suse.de
- removed the logo fading stuff, it makes problems on Radeon cards
* Tue Feb 18 2003 snwint@suse.de
- added real help text written by bg@suse.de
* Mon Feb 17 2003 snwint@suse.de
- allow more than one dialog at a time to be shown
* Fri Feb 14 2003 snwint@suse.de
- added functions for image fading
- new dialog and progress bar widgets
- added combo box for splash silent/verbose (for lilo/grub)
* Sun Feb  9 2003 snwint@suse.de
- new, extended version
* Mon Jan 20 2003 stepan@suse.de
- add OpenSchool theme
* Wed Nov 13 2002 ro@suse.de
- use x-devel-packages in neededforbuild
- use /usr/X11R6 not /usr/X11
* Fri Oct 25 2002 stepan@suse.de
- update OpenXchange theme to contain UL brand
* Thu Oct 17 2002 stepan@suse.de
- added OpenXchange theme
* Thu Sep 26 2002 snwint@suse.de
- added SuSE-SLES theme
* Fri Sep 13 2002 snwint@suse.de
- fixed UnitedLinux theme
* Wed Sep 11 2002 snwint@suse.de
- adjusted scrollbar color
- added birthday cake
* Sun Sep  8 2002 snwint@suse.de
- handle 'failsafe' properly (#18566)
- used to crash if boot image was not found
* Sat Sep  7 2002 snwint@suse.de
- improved sound code
- added mod file with birthday theme
* Mon Sep  2 2002 snwint@suse.de
- different shade of blue
* Wed Aug 28 2002 snwint@suse.de
- new SuSE theme, again
* Tue Aug 27 2002 snwint@suse.de
- apic is back
* Tue Aug 27 2002 snwint@suse.de
- new SuSE theme
* Wed Aug 21 2002 snwint@suse.de
- added UL theme
* Mon Aug 19 2002 snwint@suse.de
- added sound support
* Mon Jul 22 2002 snwint@suse.de
- accidentally left in debug code
* Wed Jul 17 2002 snwint@suse.de
- slightly changed interface to bootloader for grub
* Wed May 29 2002 snwint@suse.de
- fixed for lib64
* Thu Mar 21 2002 snwint@suse.de
- new boot image again
* Sun Mar 17 2002 snwint@suse.de
- new boot image
* Sat Mar  9 2002 snwint@suse.de
- make seven boot options fit into the boot menu
* Mon Mar  4 2002 snwint@suse.de
- added 'boot installed os' option
* Mon Feb 25 2002 snwint@suse.de
- added apic menu entry
* Mon Feb 25 2002 snwint@suse.de
- new 'failsafe' options
- increased cmdline input buffer to 256 chars
* Mon Sep 17 2001 snwint@suse.de
- new lilo/installation picture
- added password dialog (#10544)
* Sun Sep  9 2001 snwint@suse.de
- added 'rmoveto' & 'bootloader' functions
- final 7.3 lilo/installation picture
* Fri Aug 10 2001 snwint@suse.de
- use preliminary 7.3 picture
* Mon May 14 2001 snwint@suse.de
- pictures were still not correct
- added README (#7754)
* Fri May 11 2001 snwint@suse.de
- new install picture (last one was one line too short)
* Wed May  9 2001 snwint@suse.de
- new lilo/installation pictures
- copy suselilo to /boot/message (_not_ suseinstall :-/)
* Tue May  8 2001 snwint@suse.de
- moved /usr/share/gfxboot/suselilo to /boot/messsage
* Sun May  6 2001 snwint@suse.de
- in syslinux: wait for driver update disk if requested
- put space after image label in boot prompt (#7615)
* Mon Apr 30 2001 snwint@suse.de
- make it work with isolinux
* Sat Apr 28 2001 snwint@suse.de
- nearly final versions of lilo and syslinux graphics
* Sun Apr  8 2001 snwint@suse.de
- new installation and lilo logos
* Thu Apr  5 2001 snwint@suse.de
- created package
